"use strict";

require("./mocha-config.js");

var Alias = require('../../main/js/map/data/Alias');
var LayoutAlias = require('../../main/js/map/data/LayoutAlias');
var Project = require('../../main/js/map/data/Project');
var Reaction = require('../../main/js/map/data/Reaction');
var ServerConnector = require('../../main/js/ServerConnector');

var logger = require('./logger');
var chai = require('chai');
var assert = chai.assert;

describe('ServerConnector', function() {
  it('getProject', function() {
    return ServerConnector.getProject().then(function(result) {
      assert.ok(result instanceof Project);
      assert.equal(result.getProjectId(), "sample");
      assert.equal(logger.getWarnings().length, 0);
    });
  });

  it('getProjectId from GET params', function() {
    GuiConnector.getParams['id']="test";
    return ServerConnector.getProjectId().then(function(result) {
      assert.equal(result, "test");
    });
  });

  it('getReactions with empty list of ids', function() {
    return ServerConnector.getReactions([]).then(function(result) {
      assert.equal(result.length, 2);
      var reaction = result[0];
      assert.ok(reaction instanceof Reaction);
      assert.equal(reaction.getId(), 153513);
      assert.equal(reaction.getModelId(), 15781);
    });
  });

  it('getReactions without ids', function() {
    return ServerConnector.getReactions([]).then(function(result) {
      assert.equal(result.length, 2);
      var reaction = result[0];
      assert.ok(reaction instanceof Reaction);
      assert.equal(reaction.getId(), 153513);
      assert.equal(reaction.getModelId(), 15781);
    });
  });

  it('getElements with empty list of ids', function() {
    return ServerConnector.getLightAliases([]).then(function(result) {
      assert.equal(result.length, 2);
      var reaction = result[0];
      assert.ok(reaction instanceof Alias);
      assert.equal(reaction.getId(), 329176);
      assert.equal(reaction.getModelId(), 15781);
    });
  });

  it('getOverlayElements', function() {
    return ServerConnector.getOverlayElements(101).then(function(result) {
      assert.equal(result.length, 1);
      var layoutAlias = result[0];
      assert.ok(layoutAlias instanceof LayoutAlias);
      assert.equal(1.0, layoutAlias.getValue());
      assert.equal(15781, layoutAlias.getModelId());
      assert.equal(329173, layoutAlias.getId());
    });
  });

  it('idsToString', function() {
    var ids = [ 3, 2, 9, 1, 6, 8, 3, 2, 9, 1, 7, 3 ];
    var str = ServerConnector.idsToString(ids);
    assert.equal(str, "1,2,3,6,7,8,9");
  });

});
