"use strict";

var google = {
  maps : {
    event : {
      _data : [],
      addListener : function(object, type, fun) {
        google.maps.event._data.push({
          object : object,
          type : type,
          fun : fun
        });
      },
      addDomListener : function(object, type, fun) {
        object.addEventListener(type, fun);
      },
      trigger : function(object, type, param) {
        var promises = [];
        for (var i = 0; i < google.maps.event._data.length; i++) {
          var e = google.maps.event._data[i];
          if (e.object === object && e.type === type) {
            promises.push(e.fun(param));
          }
        }
        return Promise.all(promises);
      },
    },
    drawing : {
      DrawingManager : function(options) {
        this.options = options;
        if (this.options === undefined) {
          this.options = {};
        }
        this.setMap = function(map) {
          this.options.map = map;
        };
        this.setDrawingMode = function(mode) {
          this.options.drawingMode = mode;
        };
        this.getDrawingMode = function() {
          return this.options.drawingMode;
        };
      },
      OverlayType : {
        MARKER : "MARKER",
      },
    },

    ControlPosition : {
      TOP_LEFT : "TOP_LEFT",
      LEFT_BOTTOM : "LEFT_BOTTOM",
      RIGHT_BOTTOM : "RIGHT_BOTTOM",
    },
    LatLng : function(lat, lng) {
      this.latitude = parseFloat(lat);
      this.longitude = parseFloat(lng);

      this.lat = function() {
        return this.latitude;
      };
      this.lng = function() {
        return this.longitude;
      };
    },
    LatLngBounds : function(ne, sw) {
      var data = {
        ne : ne,
        sw : sw
      };
      return {
        getSouthWest : function() {
          return data.sw;
        },
        getNorthEast : function() {
          return data.ne;
        },
        isEmpty : function() {
          return ne === sw || (data.ne.lat() === sw.lat() && data.ne.lng() === sw.lng());
        },
        extend : function(arg) {
          if (data.sw === undefined) {
            data.sw = arg;
          } else {
            if (arg.lng() < data.sw.lng()) {
              data.sw.longitude = arg.lng();
            }
            if (arg.lat() < data.sw.lat()) {
              data.sw.longitude = arg.lng();
            }
          }
          if (data.ne === undefined) {
            data.ne = arg;
          } else {
            if (arg.lng() > data.ne.lng()) {
              data.ne.longitude = arg.lng();
            }

            if (arg.lat() > data.ne.lat()) {
              data.ne.longitude = arg.lng();
            }
          }
        },

      };
    },
    OverlayView : function() {
      return {};
    },
    ImageMapType : function() {
      return {};
    },
    InfoWindow : function(options) {
      this.options = options;
      if (this.options === undefined) {
        this.options = {};
      }
      this.getMap = function() {
        return this.options.map;
      };
      this.setMap = function(map) {
        this.options.map = map;
      };
      this.open = function(map) {
        this.setMap(map);
      };
      this.setContent = function() {
      };
    },
    Marker : function(options) {
      this.options = options;
      this.position = options.position;
      this.getMap = function() {
        return this.options.map;
      };
      this.setMap = function(map) {
        this.options.map = map;
      };
    },

    MarkerImage : function() {
      return {};
    },
    Map : function(div, options) {
      var data = {};
      if (options !== undefined) {
        data = options;
      }
      if (data.center === undefined) {
        data.center = new google.maps.LatLng(83.42558775689403, -135);
      }
      data.div = div;
      if (data.bounds === undefined) {
        data.bounds = new google.maps.LatLngBounds(new google.maps.LatLng(10, 10), new google.maps.LatLng(12, 12));
      }

      return {
        controls : {
          "TOP_LEFT" : [],
          "LEFT_BOTTOM" : [],
          "RIGHT_BOTTOM" : [],
        },
        getDiv : function() {
          return data.div;
        },
        mapTypes : {
          set : function() {
          },
        },
        getMapTypeId : function() {
          return data.mapTypeId;
        },
        setMapTypeId : function(id) {
          data.mapTypeId = id;
          google.maps.event.trigger(this, "maptypeid_changed", id);
        },
        setOptions : function() {
        },
        getZoom : function() {
          return data.zoom;
        },
        setZoom : function(zoom) {
          data.zoom = zoom;
        },
        getCenter : function() {
          return data.center;
        },
        setCenter : function(center) {
          data.center = center;
        },
        getBounds : function() {
          return data.bounds;
        },
        setBounds : function(bounds) {
          data.bounds = bounds;
        },
        fitBounds : function(bounds) {
          this.setBounds(bounds);
        },
      };
    },
    MVCArray : function(data) {
      if (data !== undefined) {
        this.data = data;
      } else {
        this.data = [];
      }
      this.getLength = function() {
        return this.data.length;
      };
      this.length = this.data.length;
      this.getAt = function(index) {
        return this.data[index];
      };
    },
    Point : function(x, y) {
      this.x = x;
      this.y = y;
    },
    Polyline : function(options) {
      this.options = options;
      if (this.options === undefined) {
        this.options = {};
      }
      this.setOptions = function() {
      };
      this.getPath = function() {
        return new google.maps.MVCArray();
      };
      this.getMap = function() {
        return this.options.map;
      };
      this.setMap = function(map) {
        this.options.map = map;
      };
    },
    Polygon : function(options) {
      this.options = options;
      if (this.options.paths !== undefined) {
        this.options.path = new google.maps.MVCArray(this.options.paths);
      }
      if (this.options.path === undefined) {
        this.options.path = new google.maps.MVCArray();
      }
      this.getPath = function() {
        return this.options.path;
      };
      this.getMap = function() {
        return this.options.map;
      };
      this.setMap = function(map) {
        this.options.map = map;
      };
    },
    Rectangle : function(options) {
      this.options = options;
      if (this.options === undefined) {
        this.options = {};
      }
      this.getMap = function() {
        return this.options.map;
      };
      this.setMap = function(map) {
        this.options.map = map;
      };
    },
    Size : function() {
      return {};
    },
    ZoomControlStyle : {
      LARGE : "LARGE",
    },
  }
};

google.maps.Map.prototype.fitBounds = function() {
};

module.exports = google;
