"use strict";

var Helper = require('../../Helper');

var ReactionOverlay = require('../../../../main/js/map/overlay/ReactionOverlay');

var assert = require('assert');

var logger = require('../../logger');

describe('ReactionOverlay', function() {

  var helper;
  before(function() {
    helper = new Helper();
  });

  it("Constructor", function() {
    var map = helper.createAbstractCustomMap();
    var reaction = helper.createReaction(map);
    var layoutReaction = helper.createLayoutReaction(reaction);

    var reactionOverlay = new ReactionOverlay(layoutReaction, reaction, map, false);

    assert.ok(reactionOverlay.gmapObjects);
    assert.ok(reactionOverlay.getColor());
    assert.ok(reactionOverlay.getWidth());
    assert.ok(reactionOverlay.getBounds());
    assert.ok(reactionOverlay.getReactionData());
    assert.ok(reactionOverlay.getCustomMap());
    assert.ok(reactionOverlay.getId());

  });

  it("show", function() {
    var map = helper.createCustomMap();
    var reaction = helper.createReaction(map);
    var layoutReaction = helper.createLayoutReaction(reaction);

    var reactionOverlay = new ReactionOverlay(layoutReaction, reaction, map, false);

    reactionOverlay.hide();
    assert.equal(reactionOverlay.isShown(), false);

    reactionOverlay.show();
    assert.ok(reactionOverlay.isShown());

    assert.equal(logger.getWarnings().length, 0);

    reactionOverlay.show();
    assert.ok(reactionOverlay.isShown());
    assert.equal(logger.getWarnings().length, 1);

  });

  it("createline", function() {
    var map = helper.createAbstractCustomMap();

    var line = ReactionOverlay.createLine({
      start : {
        x : 0,
        y : 10
      },
      end : {
        x : 100,
        y : 100
      },
    }, "#000000", 3, map);

    assert.ok(line);

  });
});
